@@ -81,7 +81,7 @@ def partialdep_num(
                 "Predicted Value": pred_q_centered,
             }
         )
-        df_ice = df_ice.append(df_ice_q, ignore_index=True, sort=False)
+        df_ice = pd.concat([df_ice, df_ice_q], ignore_index=True)
 
     df_mean = df_ice.groupby(by=var, as_index=False).agg({"Predicted Value": "mean"})
 
@@ -148,7 +148,7 @@ def partialdep_cat(
         df_plot_q = pd.DataFrame(
             {"id": rowid, var: x_mod[var], "Predicted Value": pred_q.values}
         )
-        df_plot = df_plot.append(df_plot_q, ignore_index=True, sort=False)
+        df_plot = pd.concat([df_plot, df_plot_q])  #  ignore_index=True, sort=False)
 
     # Convert to categorical for plotting
     df_plot[var] = (
@@ -249,7 +249,7 @@ def partialdep_datetime(
                 "Predicted Value": pred_q_centered,
             }
         )
-        df_ice = df_ice.append(df_ice_q, ignore_index=True, sort=False)
+        df_ice = pd.concat([df_ice, df_ice_q], ignore_index=True)
 
     df_mean = df_ice.groupby(by=var, as_index=False).agg({"Predicted Value": "mean"})
 
